@@ -2,7 +2,7 @@ use poem::web::Field as PoemField;
 use serde_json::Value;
 
 use crate::{
-    registry::MetaSchemaRef,
+    registry::{MetaSchemaRef, Registry},
     types::{
         ParseError, ParseFromJSON, ParseFromMultipartField, ParseResult, ToJSON, Type, TypeName,
     },
@@ -22,6 +22,10 @@ impl<T: Type> Type for JsonField<T> {
         T::schema_ref()
     }
 
+    fn register(registry: &mut Registry) {
+        T::register(registry);
+    }
+
     #[inline]
     fn as_value(&self) -> Option<&Self::ValueType> {
         self.0.as_value()
